Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/led_animation_simpletest.py
    :caption: examples/led_animation_simpletest.py
    :linenos:

Basic Animations
----------------

Demonstrates the basic animations.

.. literalinclude:: ../examples/led_animation_basic_animations.py
    :caption: examples/led_animation_basic_animations.py
    :linenos:

All Animations
----------------

Demonstrates the entire suite of animations.

.. literalinclude:: ../examples/led_animation_all_animations.py
    :caption: examples/led_animation_all_animations.py
    :linenos:

Pixel Map
---------

Demonstrates the pixel mapping feature.

.. literalinclude:: ../examples/led_animation_pixel_map.py
    :caption: examples/led_animation_pixel_map.py
    :linenos:

Animation Sequence
------------------

Demonstrates the animation sequence feature.

.. literalinclude:: ../examples/led_animation_sequence.py
    :caption: examples/led_animation_sequence.py
    :linenos:

Animation Group
---------------

Demonstrates the animation group feature.

.. literalinclude:: ../examples/led_animation_group.py
    :caption: examples/led_animation_group.py
    :linenos:

Blink
-----

Demonstrates the blink animation.

.. literalinclude:: ../examples/led_animation_blink.py
    :caption: examples/led_animation_blink.py
    :linenos:

Comet
-----

Demonstrates the comet animation.

.. literalinclude:: ../examples/led_animation_comet.py
    :caption: examples/led_animation_comet.py
    :linenos:

Chase
-----

Demonstrates the chase animation.

.. literalinclude:: ../examples/led_animation_chase.py
    :caption: examples/led_animation_chase.py
    :linenos:

Rainbow
-------

Demonstrates the rainbow animations.

.. literalinclude:: ../examples/led_animation_rainbow_animations.py
    :caption: examples/led_animation_rainbow_animations.py
    :linenos:

Sparkle
-------

Demonstrates the sparkle animations.

.. literalinclude:: ../examples/led_animation_sparkle_animations.py
    :caption: examples/led_animation_sparkle_animations.py
    :linenos:
